interface SourceResult {
    /**
     * 源码
     */
    sourceCode: string;
    /**
     * 源码文件路径
     */
    source: string;
    /**
     * 行号
     */
    line: number;
    /**
     * 列号
     */
    column: number;
}
interface SourceItem {
    source: string;
    code: string;
}

declare const isHTTPSource: (sourcePath: string) => boolean;
declare function getSourceMapFilePath(sourceJsPath: string): Promise<string | null>;
declare function getLocalSourceMapFilePath(sourceJsPath: string): string | null;
declare function getRemoteSourceMapFilePath(sourceJsPath: string): Promise<string | null>;
declare function getRemoteSource(url: string): Promise<{
    body: string;
    code?: number;
}>;
/**
 * 根据报错资源信息，获取对应源码信息
 * @param url 报错资源
 * @param line 行号
 * @param column 列号
 */
declare function getErrorSourceResult(url: string, line: number, column: number): Promise<SourceResult>;
declare function getErrorSourceResultBySourceMapUrl(sourceMapURL: string, line: number, column: number): Promise<SourceResult>;
declare function getSourceCode(url: string): Promise<string>;
declare function getErrorSourceResultBySourceMapCode(sourceMapCode: string, line: number, column: number): Promise<SourceResult>;
declare const underlineStr: (v: any) => string;
declare const yellowStr: (v: any) => string;
declare const redStr: (v: any) => string;
/**
 * @param result
 * @param showMaxLine 控制显示的行数
 */
declare function printResult(result: SourceResult, showMaxLine?: number): void;
declare function outPutResult(outputDir: string, logFilename: string, result: SourceResult, showMaxLine?: number): void;
/**
 * 通过sourceMap内容获取源文件
 */
declare function getSourcesBySourceMapCode(sourceMapCode: string): Promise<{
    source: string;
    code: string;
}[]>;
declare function outPutSources(sources: SourceItem[], outPutDir?: string): Promise<void>;

export { SourceItem, SourceResult, getErrorSourceResult, getErrorSourceResultBySourceMapCode, getErrorSourceResultBySourceMapUrl, getLocalSourceMapFilePath, getRemoteSource, getRemoteSourceMapFilePath, getSourceCode, getSourceMapFilePath, getSourcesBySourceMapCode, isHTTPSource, outPutResult, outPutSources, printResult, redStr, underlineStr, yellowStr };
